@@ -4,9 +4,9 @@
 
 DIR=jaffl-$2
 
-git clone http://github.com/wmeissner/jaffl.git $DIR
-(cd $DIR && git checkout $2)
-
+tar xzf $3
+mv wmeissner-* $DIR
 tar cfz jaffl_$2.orig.tar.gz -X debian/orig-tar.exclude $DIR
+mv jaffl_$2.orig.tar.gz ../
 
-rm -rf $DIR ../$2
+rm -rf $DIR
